==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-02 18:45+0000\nLast-Translator: Aleksey Kovalev <alexey.kovaliov@gmail.com>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Звонок"

, "Calls"
: "Звонки"

, "Line"
: "Линия"

, "Caller Id"
: "Id звонящего по телефону"

, "Start"
: "Старт"

, "Connected"
: "Соединение"

, "Disconnected"
: "Разъединение"

, "Duration"
: "Продолжительность"

, "Ringing"
: "Звонок"

, "Direction"
: "Направление"

, "Source"
: "Источник"

, "Destination"
: "Назначение"

, "Phone"
: "Телефон"

, "Phones"
: "Телефоны"

, "Settings"
: "Настройки"

, "Lines"
: "Линии"

, "Description"
: "Описание"

, "Number"
: "Номер"

, "Cancel"
: "Отменить"

, "Dial"
: "Набрать"

, "Error"
: "Ошибка"

, "Not possible to dial."
: "Не возможно набрать."

, "Edit phone settings"
: "Изменить настройки телефона"

, "Dial number"
: "Наберите номер"

, "Initiate a new outgoing call"
: "Начните новый исходящий звонок"

, "No phone selected"
: "Телефон не выбран"

, "Please select the desired phone in the tree!"
: "Пожалуйста, выберите нужный номер в дереве!"

, "Call contact"
: "Позвонить"

, "Work"
: "Рабочий"

, "Home"
: "Домашний"

, "Cell"
: "Мобильный"

, "Cell private"
: "Мобильный личный"

, "Incoming call"
: "Входящий звонок"

, "Outgoing call"
: "Исходящий звонок"

, "unknown number"
: "неизвестный номер"

, "local prefix for outgoing calls"
: "Локальный префикс для исходящих вызовов"

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: "Свой телефонный номер"

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Звонки на этой неделе"

, "Incoming and outgoing calls of this week"
: "Входящие и исходящие звонки на этой неделе"

, "Calls last week"
: "Звонки на прошлой неделе"

, "Incoming and outgoing calls of last week"
: "Входящие и исходящие звонки на прошлой неделе"

, "Calls this month"
: "Звонки в этом месяце"

, "Incoming and outgoing calls of this month"
: "Входящие и исходящие звонки в этом месяце"

, "Calls last month"
: "Звонки в прошлом месяце"

, "Incoming and outgoing calls of last month"
: "Входящие и исходящие звонки в прошлом месяце"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-02 18:45+0000\nLast-Translator: Aleksey Kovalev <alexey.kovaliov@gmail.com>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Входящий звонок"

, "Outgoing call"
: "Исходящий звонок"

, "unknown number"
: "неизвестный номер"

, "Phone"
: "Телефон"

, "Line"
: "Линия"

, "Number"
: "Номер"

, "Cancel"
: "Отменить"

, "Dial"
: "Набрать"

, "Error"
: "Ошибка"

, "Not possible to dial."
: "Не возможно набрать."

, "Call contact"
: "Позвонить"

, "Work"
: "Рабочий"

, "Home"
: "Домашний"

, "Cell"
: "Мобильный"

, "Cell private"
: "Мобильный личный"

, "Edit phone settings"
: "Изменить настройки телефона"

, "Dial number"
: "Наберите номер"

, "Initiate a new outgoing call"
: "Начните новый исходящий звонок"

, "Phones"
: "Телефоны"

, "No phone selected"
: "Телефон не выбран"

, "Please select the desired phone in the tree!"
: "Пожалуйста, выберите нужный номер в дереве!"

, "Calls this week"
: "Звонки на этой неделе"

, "Calls last week"
: "Звонки на прошлой неделе"

, "Calls this month"
: "Звонки в этом месяце"

, "Calls last month"
: "Звонки в прошлом месяце"

, "Incoming and outgoing calls of this week"
: "Входящие и исходящие звонки на этой неделе"

, "Incoming and outgoing calls of last week"
: "Входящие и исходящие звонки на прошлой неделе"

, "Incoming and outgoing calls of this month"
: "Входящие и исходящие звонки в этом месяце"

, "Incoming and outgoing calls of last month"
: "Входящие и исходящие звонки в прошлом месяце"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: "Свой телефонный номер"

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Звонок"

, "Calls"
: "Звонки"

, "Caller Id"
: "Id звонящего по телефону"

, "Start"
: "Старт"

, "Connected"
: "Соединение"

, "Disconnected"
: "Разъединение"

, "Duration"
: "Продолжительность"

, "Ringing"
: "Звонок"

, "Direction"
: "Направление"

, "Source"
: "Источник"

, "Destination"
: "Назначение"

, "resolved destination"
: ""

, "Settings"
: "Настройки"

, "Lines"
: "Линии"

, "Description"
: "Описание"


}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
